Class MainMethodSignatureCheck

All Implemented Interfaces:
JavaCheck, JavaFileScanner

public class MainMethodSignatureCheck extends IssuableSubscriptionVisitor
Checks that the "main" method has the correct signature for a program entry point.

Note, that even with a correct signature, the "main" method may not be valid entry point. For example, it may be declared in an abstract class or an interface.