Record Class UnitTestUtils.JUnit5MethodGroups

java.lang.Object
java.lang.Record
org.sonar.java.checks.helpers.UnitTestUtils.JUnit5MethodGroups
Enclosing class:
UnitTestUtils

public static record UnitTestUtils.JUnit5MethodGroups(List<MethodTree> classMethods, List<MethodTree> instanceMethods, List<MethodTree> otherMethods) extends Record
  • Constructor Details

    • JUnit5MethodGroups

      public JUnit5MethodGroups(List<MethodTree> classMethods, List<MethodTree> instanceMethods, List<MethodTree> otherMethods)
      Creates an instance of a JUnit5MethodGroups record class.
      Parameters:
      classMethods - the value for the classMethods record component
      instanceMethods - the value for the instanceMethods record component
      otherMethods - the value for the otherMethods record component
  • Method Details

    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared with Objects::equals(Object,Object).
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • classMethods

      public List<MethodTree> classMethods()
      Returns the value of the classMethods record component.
      Returns:
      the value of the classMethods record component
    • instanceMethods

      public List<MethodTree> instanceMethods()
      Returns the value of the instanceMethods record component.
      Returns:
      the value of the instanceMethods record component
    • otherMethods

      public List<MethodTree> otherMethods()
      Returns the value of the otherMethods record component.
      Returns:
      the value of the otherMethods record component