Package org.sonar.java.checks
@ParametersAreNonnullByDefault
package org.sonar.java.checks
-
ClassDescriptionThe rule checks for the use of "execute", "executeQuery" and "executeUpdate" methods on a Statement inside a loop or a "forEach" on Iterables, Maps and Streams.Checks that the "main" method has the correct signature for a program entry point.Current implementation raises the issue only for the fields used in one methodRule S6905 flags issues a query that selects all fields is executed.Rule S6889 flags issues when any sensor defined in
ReleaseSensorsCheck.AcquireReleaseSensoris not released.Suggest thatstringBuilder.append("text1" + "text2")is replaced withstringBuilder.append("text1").append("text2").Implement rule thatUse `var` instead of a type with unnamed variable (`_`) in foreach and try-with-resources.