Record Class UnitTestUtils.JUnit5MethodGroups
java.lang.Object
java.lang.Record
org.sonar.java.checks.helpers.UnitTestUtils.JUnit5MethodGroups
- Enclosing class:
UnitTestUtils
public static record UnitTestUtils.JUnit5MethodGroups(List<MethodTree> classMethods, List<MethodTree> instanceMethods, List<MethodTree> otherMethods)
extends Record
-
Constructor Summary
ConstructorsConstructorDescriptionJUnit5MethodGroups(List<MethodTree> classMethods, List<MethodTree> instanceMethods, List<MethodTree> otherMethods) Creates an instance of aJUnit5MethodGroupsrecord class. -
Method Summary
Modifier and TypeMethodDescriptionReturns the value of theclassMethodsrecord component.final booleanIndicates whether some other object is "equal to" this one.final inthashCode()Returns a hash code value for this object.Returns the value of theinstanceMethodsrecord component.Returns the value of theotherMethodsrecord component.final StringtoString()Returns a string representation of this record class.
-
Constructor Details
-
JUnit5MethodGroups
public JUnit5MethodGroups(List<MethodTree> classMethods, List<MethodTree> instanceMethods, List<MethodTree> otherMethods) Creates an instance of aJUnit5MethodGroupsrecord class.- Parameters:
classMethods- the value for theclassMethodsrecord componentinstanceMethods- the value for theinstanceMethodsrecord componentotherMethods- the value for theotherMethodsrecord component
-
-
Method Details
-
toString
-
hashCode
-
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared withObjects::equals(Object,Object). -
classMethods
Returns the value of theclassMethodsrecord component.- Returns:
- the value of the
classMethodsrecord component
-
instanceMethods
Returns the value of theinstanceMethodsrecord component.- Returns:
- the value of the
instanceMethodsrecord component
-
otherMethods
Returns the value of theotherMethodsrecord component.- Returns:
- the value of the
otherMethodsrecord component
-